.. image:: https://jazzband.co/static/img/jazzband.svg
   :target: https://jazzband.co/
   :alt: Jazzband

This is a Jazzband_ project. By contributing you agree to abide by the `Contributor Code of Conduct`_ and follow the guidelines_.

.. _Jazzband: https://jazzband.co/
.. _Contributor Code of Conduct: https://jazzband.co/about/conduct
.. _guidelines: https://jazzband.co/about/guidelines

